var manual =
[
    [ "Ogre Next Samples (Feature demonstrations)", "_samples.html", [
      [ "Showcase: Forward3D", "_samples.html#forward3d", null ],
      [ "Showcase: HDR", "_samples.html#hdr", null ],
      [ "Showcase: HDR/SMAA", "_samples.html#hdrsmaa", null ],
      [ "Showcase: PBS Materials", "_samples.html#pbsmaterials", null ],
      [ "Showcase: Post Processing", "_samples.html#postprocessing", null ],
      [ "API Usage: Animation tag points", "_samples.html#animationtagpoints", null ],
      [ "API Usage: Area Light Approximation", "_samples.html#arealighapprox", null ],
      [ "API Usage: Custom Renderable", "_samples.html#customrenderable", null ],
      [ "API Usage: Decals", "_samples.html#decals", null ],
      [ "API Usage: Dynamic Geometry", "_samples.html#dynamicgeometry", null ],
      [ "API Usage: IES Photometric Profiles", "_samples.html#iesprofiles", null ],
      [ "API Usage: Shared Skeleton", "_samples.html#sharedskeleton", null ],
      [ "API Usage: Instanced Stereo", "_samples.html#instancedstero", null ],
      [ "API Usage: Instant Radiosity", "_samples.html#instantradiosity", null ],
      [ "API Usage: Local Reflections Using Parallax Corrected Cubemaps", "_samples.html#localcubemaps", null ],
      [ "API Usage: Local Reflections Using Parallax Corrected Cubemaps With Manual Probes", "_samples.html#localcubemapsmp", null ],
      [ "API Usage: Automatic LOD Generation", "_samples.html#autolod", null ],
      [ "API Usage: Morph Animations", "_samples.html#morphanimation", null ],
      [ "API Usage: Automatically Placed Parallax Corrected Cubemap Probes Via PccPerPixelGridPlacement", "_samples.html#autopcc", null ],
      [ "API Usage: Planar Reflections", "_samples.html#planarreflections", null ],
      [ "API Usage: Refractions", "_samples.html#refractions", null ],
      [ "API Usage: SceneFormat Export / Import Sample", "_samples.html#sceneformat", null ],
      [ "API Usage: Screen Space Reflections", "_samples.html#ssreflections", null ],
      [ "API Usage: Shadow Map Debugging", "_samples.html#shadowdebug", null ],
      [ "API Usage: Shadow Map From Code", "_samples.html#shadowfromcode", null ],
      [ "API Usage: Static Shadow Map", "_samples.html#staticshadowmap", null ],
      [ "API Usage: Stencil Test", "_samples.html#stenciltest", null ],
      [ "API Usage: Stereo Rendering", "_samples.html#stereorendering", null ],
      [ "API Usage: Updating Decals And Area Lights' Textures", "_samples.html#updatedecal", null ],
      [ "API Usage: Ogre V1 Interfaces", "_samples.html#v1interface", null ],
      [ "API Usage: Ogre Next Manual Object", "_samples.html#onmanualobject", null ],
      [ "API Usage: Ogre Next V2 Meshes", "_samples.html#v2Mesh", null ],
      [ "Tutorial: Tutorial 00 - Basic", "_samples.html#tutorial00", null ],
      [ "Tutorial: Tutorial 01 - Initialisation", "_samples.html#tutorial01", null ],
      [ "Tutorial: Tutorial 02 - Variable Framerate", "_samples.html#tutorial02", null ],
      [ "Tutorial: Tutorial 03 - Deterministic Loop", "_samples.html#tutorial03", null ],
      [ "Tutorial: Tutorial 04 - Interpolation Loop", "_samples.html#tutorial04", null ],
      [ "Tutorial: Tutorial 05 - Multithreading Basics", "_samples.html#tutorial05", null ],
      [ "Tutorial: Tutorial 06 - Multithreading", "_samples.html#tutorial06", null ],
      [ "Tutorial: Compute 01 - UAV Textures", "_samples.html#compute01", null ],
      [ "Tutorial: Compute 02 - UAV Buffers", "_samples.html#compute02", null ],
      [ "Tutorial: Distortion", "_samples.html#tut_distortion", null ],
      [ "Tutorial: Dynamic Cube Map", "_samples.html#dyncubemap", null ],
      [ "Tutorial: EGL Headless", "_samples.html#eglheadless", null ],
      [ "Tutorial: Open VR", "_samples.html#openVR", null ],
      [ "Tutorial: Reconstructing Position From Depth", "_samples.html#reconpfromd", null ],
      [ "Tutorial: Rendering Sky As A Postprocess With A Single Shader", "_samples.html#skypost", null ],
      [ "Tutorial: SMAA", "_samples.html#SMAA", null ],
      [ "Tutorial: SSAO", "_samples.html#ssao", null ],
      [ "Tutorial: Terra Terrain", "_samples.html#terrain", null ],
      [ "Tutorial: Texture Baking", "_samples.html#texturebaking", null ],
      [ "Tutorial: UAV Setup 1 Example", "_samples.html#uav1", null ],
      [ "Tutorial: UAV Setup 2 Example", "_samples.html#uav2", null ]
    ] ],
    [ "Changes: Objects, Scene & Nodes", "_ogre20_changes.html", [
      [ "Names are now optional", "_ogre20_changes.html#NamesAreNowOptional", null ],
      [ "How to debug MovableObjects' (and Nodes) data", "_ogre20_changes.html#HowToDebugMovableObjectsData", [
        [ "Interpreting ArrayVector3", "_ogre20_changes.html#InterpretingArrayVector3", null ],
        [ "Dummy pointers instead of NULL", "_ogre20_changes.html#DummyPointers", null ]
      ] ],
      [ "Attachment and Visibility", "_ogre20_changes.html#AttachmentAndVisibility", null ],
      [ "Attaching/Detaching is more expensive than hiding", "_ogre20_changes.html#AttachingDetachingIsMoreExpensive", null ],
      [ "All MovableObjects require a SceneNode (Lights & Cameras)", "_ogre20_changes.html#AllMovableObjectsRequireSceneNode", null ],
      [ "Obtaining derived transforms", "_ogre20_changes.html#DerivedTransforms", null ],
      [ "SCENE_STATIC and SCENE_DYNAMIC", "_ogre20_changes.html#SceneStaticSceneDynamic", [
        [ "What means a Node to be SCENE_STATIC", "_ogre20_changes.html#SceneStaticNode", null ],
        [ "What means a Entities (and InstancedEntities) to be SCENE_STATIC", "_ogre20_changes.html#SceneStaticEntities", null ],
        [ "General", "_ogre20_changes.html#SceneStaticGeneral", null ]
      ] ],
      [ "Ogre asserts mCachedAabbOutOfDate or mCachedTransformOutOfDate while in debug mode", "_ogre20_changes.html#AssersionCachedOutOfDate", null ],
      [ "Custom classes derived from Renderable or MovableObject", "_ogre20_changes.html#DerivingRenderable", null ],
      [ "How do I get the vertex information from the new v2 Mesh classes?", "_ogre20_changes.html#V2MeshInformation", null ],
      [ "How do I set the element offsets, vertex buffer's source and index?", "_ogre20_changes.html#V2MeshElementOffset", null ],
      [ "My scene looks too dark or dull!", "_ogre20_changes.html#SceneLooksDarkDull", null ],
      [ "I activated gamma correction, but now my GUI textures look washed out!", "_ogre20_changes.html#GUIWashedOut", null ]
    ] ],
    [ "Technical Overview", "_technical_overview.html", [
      [ "Overview", "_technical_overview.html#TechnicalOverviewOverview", [
        [ "SIMD Coherence", "_technical_overview.html#SIMDCoherence", null ]
      ] ],
      [ "Memory Managers usage patterns", "_technical_overview.html#MemoryManagerUsagePatterns", [
        [ "Cleanups", "_technical_overview.html#MemoryManagerCleanups", null ]
      ] ],
      [ "Memory preallocation", "_technical_overview.html#MemoryPreallocation", null ],
      [ "Configuring memory managers", "_technical_overview.html#ConfiguringMemoryManagers", null ],
      [ "Where is RenderTarget::update? Why do I get errors in Viewport?", "_technical_overview.html#RenderTargetUpdate", null ],
      [ "Porting from 1.x to 2.0", "_technical_overview.html#PortingV1ToV2", null ],
      [ "Porting from 2.0 to 2.1", "_technical_overview.html#PortingV20ToV21", null ]
    ] ],
    [ "Compositor", "compositor.html", [
      [ "Nodes", "compositor.html#CompositorNodes", [
        [ "Input & output channels and RTTs", "compositor.html#CompositorNodesChannelsAndRTTs", [
          [ "Locally declared textures", "compositor.html#CompositorNodesChannelsAndRTTsLocalTextures", null ],
          [ "It comes from an input channel", "compositor.html#CompositorNodesChannelsAndRTTsFromInputChannel", null ],
          [ "It is a global texture", "compositor.html#CompositorNodesChannelsAndRTTsGlobal", null ],
          [ "Main RenderTarget", "compositor.html#CompositorNodesChannelsAndRTTsMainRenderTarget", null ]
        ] ],
        [ "Target", "compositor.html#CompositorNodesTarget", null ],
        [ "Passes", "compositor.html#CompositorNodesPasses", [
          [ "clear", "compositor.html#CompositorNodesPassesClear", null ],
          [ "generate_mipmaps", "compositor.html#CompositorNodesPassesGenerateMipmaps", null ],
          [ "quad", "compositor.html#CompositorNodesPassesQuad", null ],
          [ "resolve", "compositor.html#CompositorNodesPassesResolve", null ],
          [ "render_scene", "compositor.html#CompositorNodesPassesRenderScene", null ],
          [ "shadows", "compositor.html#CompositorNodesPassesShadows", null ],
          [ "stencil", "compositor.html#CompositorNodesPassesStencil", null ],
          [ "uav_queue", "compositor.html#CompositorNodesPassesUavQueue", [
            [ "Synchronization", "compositor.html#CompositorNodesPassesUavQueueSync", null ]
          ] ],
          [ "compute", "compositor.html#CompositorNodesPassesCompute", null ]
        ] ],
        [ "Textures", "compositor.html#CompositorNodesTextures", [
          [ "MSAA: Explicit vs Implicit resolves", "compositor.html#CompositorNodesTexturesMsaa", [
            [ "Implicit resolves", "compositor.html#CompositorNodesTexturesMsaaImplicit", null ],
            [ "Explicit resolves", "compositor.html#CompositorNodesTexturesMsaaExplicit", null ],
            [ "Resources", "compositor.html#CompositorNodesTexturesMsaaResources", null ]
          ] ],
          [ "Depth Textures", "compositor.html#CompositorNodesTexturesDepth", null ]
        ] ]
      ] ],
      [ "Shadow Nodes", "compositor.html#CompositorShadowNodes", [
        [ "Setting up shadow nodes", "compositor.html#CompositorShadowNodesSetup", null ],
        [ "Example", "compositor.html#CompositorShadowNodesExample", null ],
        [ "Shadow map atlas & Point Lights", "compositor.html#CompositorShadowNodesAtlasAndPointLights", null ],
        [ "Reuse, recalculate and first", "compositor.html#CompositorShadowNodesReuseEtc", null ],
        [ "Shadow mapping setup types", "compositor.html#CompositorShadowNodesTypes", [
          [ "Uniform shadow mapping", "compositor.html#CompositorShadowNodesTypesUniform", null ],
          [ "Focused", "compositor.html#CompositorShadowNodesTypesFocused", null ],
          [ "PSSM / CSM", "compositor.html#CompositorShadowNodesTypesPssm", null ],
          [ "Plane Optimal", "compositor.html#CompositorShadowNodesTypesPlaneOptimal", null ]
        ] ],
        [ "Writing shaders", "compositor.html#CompositorShadowNodesShaders", null ]
      ] ],
      [ "Workspaces", "compositor.html#CompositorWorkspaces", [
        [ "Data dependencies between nodes and circular dependencies", "compositor.html#CompositorWorkspacesDataDependencies", null ]
      ] ],
      [ "Setting up code", "compositor.html#CompositorSetupCode", [
        [ "Initializing the workspace", "compositor.html#CompositorWorkspacesSetupInitialize", null ],
        [ "Simple bootstrap for beginners", "compositor.html#CompositorWorkspacesSetupSimple", null ],
        [ "Advanced C++ users", "compositor.html#CompositorWorkspacesSetupAdvanced", null ]
      ] ],
      [ "Stereo and Split-Screen Rendering", "compositor.html#StereoAndSplitScreenRendering", [
        [ "Per-Workspace offset and scale", "compositor.html#CompositorWorkspacesStereoPerWorkspace", null ],
        [ "Viewport modifier mask", "compositor.html#CompositorWorkspacesStereoViewportMask", null ],
        [ "Execution mask", "compositor.html#CompositorWorkspacesStereoExecutionMask", null ],
        [ "Default values", "compositor.html#CompositorWorkspacesStereoDefaultValues", null ]
      ] ],
      [ "Advanced MSAA", "compositor.html#autotoc_md70", [
        [ "What is MSAA?", "compositor.html#autotoc_md71", [
          [ "Supersampling Antialiasing (SSAA) vs MSAA", "compositor.html#autotoc_md72", null ],
          [ "MSAA approach to the problem", "compositor.html#autotoc_md73", null ]
        ] ],
        [ "Ogre + MSAA with Implicit Resolves", "compositor.html#autotoc_md74", null ],
        [ "Ogre + MSAA with Explicit Resolves", "compositor.html#autotoc_md75", null ]
      ] ]
    ] ],
    [ "Global Illumination Methods", "_gi_methods.html", [
      [ "Ambient Lighting", "_gi_methods.html#GiAmbientLighting", [
        [ "Flat", "_gi_methods.html#GiAmbientLightingFlat", null ],
        [ "Hemisphere", "_gi_methods.html#GiAmbientLightingHemisphere", null ],
        [ "Spherical Harmonics", "_gi_methods.html#GiAmbientLightingSH", null ]
      ] ],
      [ "Parallax Corrected Cubemaps (PCC)", "_gi_methods.html#GiPCC", [
        [ "Auto PCC", "_gi_methods.html#GiPCCAuto", null ],
        [ "Manual PCC", "_gi_methods.html#GiPCCManual", null ]
      ] ],
      [ "Per Pixel PCC", "_gi_methods.html#GiPPPCC", [
        [ "PCC Per Pixel Grid Placement", "_gi_methods.html#GiPPGridPlacement", null ]
      ] ],
      [ "Instant Radiosity", "_gi_methods.html#GiInstantRadiosity", null ],
      [ "Irradiance Volume", "_gi_methods.html#GiIrradianceVolume", null ],
      [ "Voxel Cone Tracing (aka VCT)", "_gi_methods.html#GiVCT", [
        [ "VCT + Per Pixel PCC Hybrid", "_gi_methods.html#GiVCTPlusPPPCC", null ]
      ] ],
      [ "Irradiance Field with Depth (IFD)", "_gi_methods.html#GiIFD", null ],
      [ "What technique should I choose?", "_gi_methods.html#GiWhatTechniqueChoose", null ]
    ] ],
    [ "Instancing", "instancing.html", [
      [ "What is instancing?", "instancing.html#WhatIsInstancing", null ],
      [ "Instancing 101", "instancing.html#Instancing101", [
        [ "Instances per batch", "instancing.html#InstancesPerBatch", null ]
      ] ],
      [ "Techniques", "instancing.html#InstancingTechniques", [
        [ "ShaderBased", "instancing.html#InstancingTechniquesShaderBased", null ],
        [ "VTF (Software)", "instancing.html#InstancingTechniquesVTFSoftware", null ],
        [ "HW VTF", "instancing.html#InstancingTechniquesHWVTF", [
          [ "HW VTF LUT", "instancing.html#InstancingTechniquesHW", null ]
        ] ],
        [ "HW Basic", "instancing.html#InstancingTechniquesHWBasic", null ]
      ] ],
      [ "Custom parameters", "instancing.html#InstancingCustomParameters", null ],
      [ "Supporting multiple submeshes", "instancing.html#InstancingMultipleSubmeshes", null ],
      [ "Defragmenting batches", "instancing.html#InstancingDefragmentingBatches", [
        [ "What is batch fragmentation?", "instancing.html#InstancingDefragmentingBatchesIntro", null ],
        [ "Prevention: Avoiding fragmentation", "instancing.html#InstancingDefragmentingBatchesPrevention", null ],
        [ "Cure: Defragmenting on the fly", "instancing.html#InstancingDefragmentingBatchesOnTheFly", null ]
      ] ],
      [ "Troubleshooting", "instancing.html#InstancingTroubleshooting", null ]
    ] ],
    [ "Threading", "threading.html", [
      [ "Initializing", "threading.html#ThreadingInitializing", [
        [ "Ideal number of threads", "threading.html#ThreadingInitializingNumberOfThreads", null ],
        [ "More info about InstancingThreadedCullingMethod", "threading.html#ThreadingInitializingCullingMethod", null ]
      ] ],
      [ "What tasks are threaded in Ogre", "threading.html#ThreadingInOgre", null ],
      [ "Using Ogre's threading system for custom tasks", "threading.html#ThreadingCustomTasks", null ],
      [ "Thread safety of SceneNodes", "threading.html#ThreadSafetySceneNodes", null ]
    ] ],
    [ "Performance Hints", "performance.html", null ],
    [ "HLMS: High Level Material System", "hlms.html", [
      [ "Fundamental changes", "hlms.html#HlmsChanges", [
        [ "Viewports and Scissor tests", "hlms.html#HlmsChangesViewports", null ],
        [ "A lot of data is stored in \"Blocks\"", "hlms.html#HlmsChangesBlocks", null ],
        [ "Materials are still alive", "hlms.html#HlmsChangesMaterialsAlive", null ],
        [ "Fixed Function has been removed", "hlms.html#HlmsChangesFFP", null ]
      ] ],
      [ "The three components", "hlms.html#HlmsComponents", null ],
      [ "Blocks", "hlms.html#HlmsBlocks", [
        [ "Datablocks", "hlms.html#HlmsBlocksDatablocks", null ],
        [ "Macroblocks", "hlms.html#HlmsBlocksMacroblocks", null ],
        [ "Blendblocks", "hlms.html#HlmsBlocksBlendblocks", null ],
        [ "Samplerblocks", "hlms.html#HlmsBlocksSampleblocks", null ]
      ] ],
      [ "Hlms templates", "hlms.html#HlmsTemplates", null ],
      [ "The Hlms preprocessor", "hlms.html#HlmsPreprocessor", [
        [ "Preprocessor syntax", "hlms.html#HlmsPreprocessorSyntax", [
          [ "@property( expression )", "hlms.html#HlmsPreprocessorSyntaxProperty", null ],
          [ "@foreach( count, scopedVar, [start] )", "hlms.html#HlmsPreprocessorSyntaxForeach", null ],
          [ "@counter( variable )", "hlms.html#HlmsPreprocessorSyntaxCounter", null ],
          [ "@value( variable )", "hlms.html#HlmsPreprocessorSyntaxValue", null ],
          [ "@set add sub mul div mod min max", "hlms.html#HlmsPreprocessorSyntaxSetEtc", null ],
          [ "@piece( nameOfPiece )", "hlms.html#HlmsPreprocessorSyntaxPiece", null ],
          [ "@insertpiece( nameOfPiece )", "hlms.html#HlmsPreprocessorSyntaxInsertpiece", null ],
          [ "@undefpiece( nameOfPiece )", "hlms.html#HlmsPreprocessorSyntaxUndefpiece", null ],
          [ "@pset padd psub pmul pdiv pmod pmin pmax", "hlms.html#HlmsPreprocessorSyntaxPsetEtc", null ]
        ] ]
      ] ],
      [ "Creation of shaders", "hlms.html#HlmsCreationOfShaders", [
        [ "C++ interaction with shader templates", "hlms.html#HlmsCreationOfShadersCpp", null ],
        [ "Common conventions", "hlms.html#HlmsCreationOfShadersConventions", null ],
        [ "Hot reloading", "hlms.html#HlmsCreationOfShadersHotReloading", null ],
        [ "Disabling a stage", "hlms.html#HlmsCreationOfShadersDisablingStage", null ],
        [ "Customizing an existing implementation", "hlms.html#HlmsCreationOfShadersCustomizing", null ]
      ] ],
      [ "Run-time rendering", "hlms.html#HlmsRuntimeRendering", [
        [ "preparePassHash", "hlms.html#HlmsRuntimeRenderingPreparePassHash", null ],
        [ "fillBuffersFor", "hlms.html#HlmsRuntimeRenderingFillBuffersFor", null ]
      ] ],
      [ "Using the HLMS implementations", "hlms.html#UsingHlmsImplementation", [
        [ "Initialization", "hlms.html#UsingHlmsImplementationInitialization", null ],
        [ "Deinitialization", "hlms.html#UsingHlmsImplementationDeinitilization", null ],
        [ "Creating a datablock", "hlms.html#UsingHlmsImplementationCreatingDatablock", null ]
      ] ],
      [ "The Hlms Texture Manager", "hlms.html#HlmsTextureManager", [
        [ "Automatic batching", "hlms.html#HlmsTextureManagerAutomaticBatching", [
          [ "Texture types", "hlms.html#HlmsTextureManagerAutomaticBatchingTextureTypes", null ],
          [ "Automatic parameters", "hlms.html#HlmsTextureManagerAutomaticBatchingAutoParams", null ],
          [ "Loading a texture twice (i.e. with a different format) via aliasing", "hlms.html#HlmsTextureManagerAutomaticBatchingLoadingTwice", null ]
        ] ],
        [ "Manual: Texture packs", "hlms.html#HlmsTextureManagerTexturePacks", null ],
        [ "Watching out for memory consumption", "hlms.html#HlmsTextureManagerWatchOutMemory", [
          [ "Additional memory considerations", "hlms.html#HlmsTextureManagerWatchOutMemoryConsiderations", null ],
          [ "setWorkerThreadMinimumBudget warning", "hlms.html#setWorkerThreadMinimumBudget", null ]
        ] ]
      ] ],
      [ "Troubleshooting", "hlms.html#HlmsTroubleshooting", [
        [ "My shadows don't show up or are very glitchy", "hlms.html#HlmsTroubleshootingShadow", null ]
      ] ]
    ] ],
    [ "AZDO changes (Aproaching Zero Driver Overhead)", "azdo.html", [
      [ "V2 and v1 objects", "azdo.html#V2AndV1Objects", [
        [ "Longevity of the v1 objects and deprecation", "azdo.html#V2AndV1ObjectsV1Longevity", null ]
      ] ],
      [ "Render Queue", "azdo.html#RenderQueue", null ],
      [ "The VaoManager", "azdo.html#VaoMaanger", null ]
    ] ],
    [ "The Command Buffer", "commandbuffer.html", [
      [ "Adding a command", "commandbuffer.html#CommandBufferAddCommand", null ],
      [ "Structure of a command", "commandbuffer.html#CommandBufferCommandStructure", null ],
      [ "Execution table", "commandbuffer.html#CommandBufferExecutionTable", [
        [ "Hacks and Tricks", "commandbuffer.html#CommandBufferExecutionTableHacks", null ]
      ] ],
      [ "Post-processing the command buffer", "commandbuffer.html#CommandBufferPostProcessing", null ]
    ] ],
    [ "Terra System", "_terra_system.html", [
      [ "Vertex-bufferless rendering", "_terra_system.html#autotoc_md61", null ],
      [ "Vertex Trick in Terra", "_terra_system.html#autotoc_md62", null ],
      [ "Terra cells", "_terra_system.html#autotoc_md63", [
        [ "First layer, the 4x4 block", "_terra_system.html#autotoc_md64", null ],
        [ "Outer layers", "_terra_system.html#autotoc_md65", null ]
      ] ],
      [ "Skirts", "_terra_system.html#autotoc_md66", null ],
      [ "Shadows", "_terra_system.html#autotoc_md67", null ],
      [ "Shading", "_terra_system.html#autotoc_md68", null ],
      [ "Why is it not a component?", "_terra_system.html#autotoc_md69", null ]
    ] ],
    [ "Tunning memory consumption and resources", "_tuning_memory_resources.html", [
      [ "Grouping textures by type", "_tuning_memory_resources.html#GroupingTexturesByType", null ],
      [ "Dynamic vs Default buffers", "_tuning_memory_resources.html#DynamicVsDefaultBuffers", null ],
      [ "Tweaking default memory consumption by VaoManager", "_tuning_memory_resources.html#TweakingVaoManager", [
        [ "Vulkan and <tt>TEXTURES_OPTIMAL</tt>", "_tuning_memory_resources.html#autotoc_md28", null ]
      ] ]
    ] ],
    [ "What's new in Ogre 2.2", "_ogre22_changes.html", [
      [ "Load Store semantics", "_ogre22_changes.html#autotoc_md29", [
        [ "Now that we’ve explained how TBDRs work, we can explain load and store actions", "_ogre22_changes.html#autotoc_md30", null ]
      ] ],
      [ "More control over MSAA", "_ogre22_changes.html#autotoc_md31", null ],
      [ "Porting to Ogre 2.2 from 2.1", "_ogre22_changes.html#autotoc_md32", [
        [ "PixelFormats", "_ogre22_changes.html#autotoc_md33", [
          [ "Common pixel format equivalencies", "_ogre22_changes.html#autotoc_md34", null ]
        ] ],
        [ "Useful code snippets", "_ogre22_changes.html#autotoc_md35", [
          [ "Create a TextureGpu based on a file", "_ogre22_changes.html#autotoc_md36", null ],
          [ "Create a TextureGpu based that you manually fill", "_ogre22_changes.html#autotoc_md37", null ],
          [ "Uploading data to a TextureGpu", "_ogre22_changes.html#autotoc_md38", null ],
          [ "Upload streaming", "_ogre22_changes.html#autotoc_md39", null ],
          [ "Downloading data from TextureGpu into CPU", "_ogre22_changes.html#autotoc_md40", null ],
          [ "Downloading streaming", "_ogre22_changes.html#autotoc_md41", null ]
        ] ]
      ] ],
      [ "Difference between depth, numSlices and depthOrSlices", "_ogre22_changes.html#autotoc_md42", null ],
      [ "Memory layout of textures and images", "_ogre22_changes.html#autotoc_md43", null ],
      [ "Troubleshooting errors", "_ogre22_changes.html#autotoc_md44", null ],
      [ "RenderPassDescriptors", "_ogre22_changes.html#autotoc_md45", null ],
      [ "DescriptorSetTexture & co.", "_ogre22_changes.html#autotoc_md46", null ],
      [ "Does 2.2 interoperate well with the HLMS texture arrays?", "_ogre22_changes.html#autotoc_md47", null ],
      [ "Hlms porting", "_ogre22_changes.html#autotoc_md48", null ],
      [ "Things to watch out when porting", "_ogre22_changes.html#autotoc_md49", null ]
    ] ],
    [ "Behavor of StagingTexture in D3D11", "_behavor_staging_texture_d3_d11.html", [
      [ "Attempting to be contiguous", "_behavor_staging_texture_d3_d11.html#autotoc_md17", null ],
      [ "Slicing in 3", "_behavor_staging_texture_d3_d11.html#autotoc_md18", null ],
      [ "Slicing in the middle", "_behavor_staging_texture_d3_d11.html#autotoc_md19", null ]
    ] ],
    [ "What's new in Ogre 2.3", "_ogre23_changes.html", [
      [ "Switch importV1 to createByImportingV1", "_ogre23_changes.html#autotoc_md50", null ],
      [ "Shadow's Normal Offset Bias", "_ogre23_changes.html#autotoc_md51", null ],
      [ "Unlit vertex and pixel shaders unified", "_ogre23_changes.html#autotoc_md52", null ],
      [ "Added HlmsMacroblock::mDepthClamp", "_ogre23_changes.html#autotoc_md53", null ],
      [ "Added shadow pancaking", "_ogre23_changes.html#autotoc_md54", null ],
      [ "Other relevant information when porting", "_ogre23_changes.html#autotoc_md55", [
        [ "Do not call notifyDataIsReady more than needed", "_ogre23_changes.html#autotoc_md56", null ],
        [ "Global changes for Vulkan compatibility:", "_ogre23_changes.html#autotoc_md57", null ]
      ] ]
    ] ],
    [ "Root Layouts", "_root_layouts.html", [
      [ "Old APIs (i.e. D3D11 and GL)", "_root_layouts.html#RootLayoutsOldAPIs", null ],
      [ "New APIs and Root Layouts", "_root_layouts.html#RootLayoutsNewAPIs", null ],
      [ "Setting up root layouts", "_root_layouts.html#RootLayoutsSettingUp", [
        [ "Could you have used e.g. \"const_buffers\" : [0,7] instead of [4,7]?", "_root_layouts.html#autotoc_md58", null ]
      ] ],
      [ "Declaring Root Layouts in shaders", "_root_layouts.html#RootLayoutsDeclaringInShaders", null ],
      [ "Baked sets", "_root_layouts.html#RootLayoutsBakedSets", null ],
      [ "Prefab Root Layouts for low level materials", "_root_layouts.html#RootLayoutPrefabs", null ],
      [ "Arrays of Textures", "_root_layouts.html#RootLayoutsArraysOfTextures", [
        [ "C++", "_root_layouts.html#RootLayoutsAoTCpp", null ],
        [ "Inline shader declaration", "_root_layouts.html#RootLayoutsAoTInlineShader", null ],
        [ "Automatic", "_root_layouts.html#RootLayoutsAoTAuto", null ],
        [ "Making GLSL shaders compatible with both Vulkan and OpenGL", "_root_layouts.html#RootLayoutsGLSLForGLandVK", [
          [ "Example:", "_root_layouts.html#RootLayoutsGLSLForGLandVKExample", [
            [ "OpenGL", "_root_layouts.html#autotoc_md59", null ],
            [ "Vulkan", "_root_layouts.html#autotoc_md60", null ]
          ] ]
        ] ]
      ] ]
    ] ]
];